/*
 * Servo test program for RFID treasure hunt box. www.instructables.com/
 * This sketch allows for serial monitor control of servo for testing of RFID treasure hunt Box
 * last updated 6-21-23 E.Linville
 * attach servo pin to arduino pin 2. This will work with any arduino
 * start by removing the servo horn from the servo so that any movement doesnt bend anything then upload the sketch
 * The sketch will start by setting the servo to the center position. install the servo horn so that it sticks to the side 90 degrees 
 * open the serial monitor and set the baud rating to 115200 (lower right corner of Serial monitor window)
 * When the letter o is typed in the serial monitor the servo will move to the open position
 * when the letter c is typed in the serial monitor the servo will move to the closed position
 * when the letter m is typed in the serial monitor the servo will move to the middle position (1500 or center of servo movement)
 *  Below are three int variables that control the movement of the servo. DO NOT ADJUST THE MIDDLE VALUE.
 *  Once you have the servo adusted correctly type the letter o into the serial monitor and press enter. the servo will move to the open
 * position. The values are deliberatly set too short so that you will have to adjust them to the proper value.
 *  For the open value, change the number farther away (greater than) from the center value (1500) for it to move more open 
 * or to turn the servo more counter-clockwise.
 *  Alter the number of the open value a little at a time and re-upload the sketch after each change until the pin is just flush with the tab. 
 * you will have to press o to move to the open position after every upload to move to the open position
 *  Once you have the open value set type c into the serial monitor and press enter. The servo will move to the closed position.
 *  For the closed value change the number farther away (less than) from the center value (1500) for it to move more closed
 * or to turn the servo more clockwise.
 * alter the number of the closed value a little at a time and re-upload the sketch after each change until the pin sticks out just a bit 
 * short of even with the edge of the plexiglas. 
 *  NOTE: IF YOU SET THIS TOO FAR OUT THE SERVO WILL HUM AND CONSUME POWER CONSTANTLY. 
 *  You want the tip of the pin to come out just shy of the side of the box when the cover is installed 
 *  You will have to type c into the serial monitor after every upload to move to the closed position
 *  NOTE: the max/min values of a servo are 1000 for all the way clockwise and 2000 for all the way counter-clockwise
 *  When you have gotten the values correct so that you can switch from open to closed position and the pin moves smoothly
 *  go back to the instructable and continue with the next step
 */

#include <Servo.h>
int servoOpen=1800; //setting for when box is unlocked (counter-clockwise rotation)
int servoMiddle=1500; //center of servo throw
int servoClosed=1500; //setting for when the box is locked (clocwise rotation)
//my settings were 1800 for open and 1500 for closed
Servo boxServo; //define servo name

void setup() {
  Serial.begin(115200); // Initialize serial port to send and receive at 115200 baud
  Serial.println("----------SerialMonitor_servoTest_v1.0---------------");
  Serial.println("enter o into serial monitor to move servo to open position");
  Serial.println("enter m into serial monitor to move servo to middle position");
  Serial.println("enter c into serial monitor to move servo to closed position");
  boxServo.attach(2); //assign the servo to pin 2
  boxServo.writeMicroseconds(servoMiddle); //initally set the servo to goto middle of throw
}//end of setup

void loop() {

   if ( Serial.available()) // Check the serial monitor to see if at least one character is available
  {
    char ch = Serial.read();

    if(ch == 'o') // if char from serial monitor is a o then ...
    {
      Serial.println("Servo Open");
      boxServo.writeMicroseconds(servoOpen);
    }//end of if(ch == o)

    if(ch == 'm')// if char from serial monitor is a m then ...
    {
      Serial.println("Servo Middle");
      boxServo.writeMicroseconds(servoMiddle);
    }

    if(ch == 'c')// if char from serial monitor is a c then ...
    {
      Serial.println("Servo Closed");
      boxServo.writeMicroseconds(servoClosed);
    }
  }//end of if (Serial.available())
} //end of loop
